Metal Complexes
===============

.. toctree::
  :maxdepth: 1

  Overview and Examples <_autosummary/stk.metal_complex.MetalComplex>
  Paddlewheel <_autosummary/stk.metal_complex.Paddlewheel>
  Porphyrin <_autosummary/stk.metal_complex.Porphyrin>
  Octahedral <_autosummary/stk.metal_complex.Octahedral>
  Octahedral Lambda <_autosummary/stk.metal_complex.OctahedralLambda>
  Octahedral Delta <_autosummary/stk.metal_complex.OctahedralDelta>
  Square Planar <_autosummary/stk.metal_complex.SquarePlanar>
  Bidentate Square Planar <_autosummary/stk.metal_complex.BidentateSquarePlanar>
  Cis Protected Square Planar <_autosummary/stk.metal_complex.CisProtectedSquarePlanar>
